# UETSchedule

UETSchedule is a Python script that automates the process of scheduling courses at UET. It is designed to save students time and effort in creating their schedules.
## Installation

You can install AutoSchedule using pip. First, make sure you have Python 3.7 or higher installed. Then, open a terminal window and type the following command:
```bash
pip install UETSchedule
```
If you're using virtualenv, you can activate your environment first and then run the command above.
Usage

```bash
Usage: schedule [OPTIONS]

Options:
  --student-id TEXT     The id of student.  [required]
  --user-mail TEXT      The google account to create event.  [required]
  --calendar-name TEXT  The calendar name. Default `Schedule`.
  --help                Show this message and exit.
```

## License

AutoSchedule is licensed under the GPL-3.0 license. See the LICENSE.md file for more details.
Contributing

If you find a bug or want to suggest a new feature, please open an issue on the AutoSchedule GitHub page. We welcome contributions from the community!
